@@ -45,8 +45,7 @@ struct AutoClose
     }
 };
 
-void takePersistableUriPermission(const QJniObject& intent,
-                                  const QJniObject& uri);
+void takePersistableUriPermission(const QJniObject& uri);
 
 QJniObject getContext()
 {
@@ -78,7 +77,7 @@ QString getDisplayName(QJniObject uri)
                 "[Ljava/lang/String;Ljava/lang/String;)"
                 "Landroid/database/Cursor;",
                 uri.object(), projection, nullptr, nullptr, nullptr);
-    if (env->ExceptionCheck())
+    if (! cursor.isValid())
         return {};
     AutoClose autoClose{cursor};
     if (! cursor.callMethod<jboolean>("moveToFirst"))
@@ -183,26 +182,23 @@ void startDocumentActivity(
         if (! uriString.isValid())
             return;
         if (takePersistablePermission)
-            takePersistableUriPermission(data, uri);
+            takePersistableUriPermission(uri);
         auto displayName = getDisplayName(uri);
         callback(uriString.toString(), displayName);
     });
 }
 
-void takePersistableUriPermission(const QJniObject& intent,
-                                  const QJniObject& uri)
+void takePersistableUriPermission(const QJniObject& uri)
 {
     auto contentResolver = getContentResolver();
     if (! contentResolver.isValid())
         return;
-    auto flags = intent.callMethod<jint>("getFlags");
-    auto flagRead = QJniObject::getStaticField<jint>(
-                "android/content/Intent", "FLAG_GRANT_READ_URI_PERMISSION");
-    auto flagWrite = QJniObject::getStaticField<jint>(
-                "android/content/Intent", "FLAG_GRANT_WRITE_URI_PERMISSION");
     contentResolver.callMethod<void>(
                 "takePersistableUriPermission", "(Landroid/net/Uri;I)V",
-                uri.object(), flags & (flagRead | flagWrite));
+                uri.object(),
+                0x00000001 // FLAG_GRANT_READ_URI_PERMISSION
+                | 0x00000002 // FLAG_GRANT_WRITE_URI_PERMISSION
+                );
 }
 
 #endif
@@ -346,45 +342,55 @@ void AndroidUtils::initTheme([[maybe_unused]]QColor colorBackground)
                                                     "()Landroid/view/Window;");
         if (! window.isValid())
             return;
-        auto flagDrawsSystemBarBackgrounds =
-                QJniObject::getStaticField<jint>(
-                    "android/view/WindowManager$LayoutParams",
-                    "FLAG_DRAWS_SYSTEM_BAR_BACKGROUNDS");
-        window.callMethod<void>("addFlags", "(I)V",
-                                flagDrawsSystemBarBackgrounds);
-        auto flagTranslucentStatus =
-                QJniObject::getStaticField<jint>(
-                    "android/view/WindowManager$LayoutParams",
-                    "FLAG_TRANSLUCENT_STATUS");
-        window.callMethod<void>("clearFlags", "(I)V", flagTranslucentStatus);
+        window.callMethod<void>(
+                    "addFlags", "(I)V",
+                    0x80000000 /* FLAG_DRAWS_SYSTEM_BAR_BACKGROUNDS */);
+        window.callMethod<void>("clearFlags", "(I)V",
+                                0x04000000 /* FLAG_TRANSLUCENT_STATUS */);
         auto view = window.callObjectMethod("getDecorView",
                                             "()Landroid/view/View;");
-        // Note: getSystemUiVisibility() has been deprecated in API 30,
-        // in the future use WindowInsetsController for API >= 30
         bool isLight = (colorBackground.lightness() > 128);
-        int visibility = view.callMethod<int>("getSystemUiVisibility", "()I");
-        auto systemUiFlagLightStatusBar =
-                QJniObject::getStaticField<jint>(
-                    "android/view/View", "SYSTEM_UI_FLAG_LIGHT_STATUS_BAR");
-        if (isLight)
-            visibility |= systemUiFlagLightStatusBar;
-        else
-            visibility &= ~systemUiFlagLightStatusBar;
-        if (QAndroidApplication::sdkVersion() >= 26)
+        if (QAndroidApplication::sdkVersion() < 30)
         {
-            auto systemUiFlagLightNavigationBar =
-                    QJniObject::getStaticField<jint>(
-                        "android/view/View", "SYSTEM_UI_FLAG_LIGHT_NAVIGATION_BAR");
+            int visibility =
+                    view.callMethod<int>("getSystemUiVisibility", "()I");
             if (isLight)
-                visibility |= systemUiFlagLightNavigationBar;
+                visibility |= 0x00002000; // SYSTEM_UI_FLAG_LIGHT_STATUS_BAR
             else
-                visibility &= ~systemUiFlagLightNavigationBar;
+                visibility &= ~0x00002000;
+            if (QAndroidApplication::sdkVersion() >= 26)
+            {
+                if (isLight)
+                    visibility |= 0x00000010; // SYSTEM_UI_FLAG_LIGHT_NAVIGATION_BAR
+                else
+                    visibility &= ~0x00000010;
+            }
+            view.callMethod<void>("setSystemUiVisibility", "(I)V", visibility);
+        }
+        else // QAndroidApplication::sdkVersion() >= 30
+        {
+            auto insetsController =
+                    view.callObjectMethod(
+                        "getWindowInsetsController",
+                        "()Landroid/view/WindowInsetsController;");
+            if (isLight)
+                insetsController.callMethod<void>(
+                            "setSystemBarsAppearance", "(II)V",
+                            0x00000008 // APPEARANCE_LIGHT_STATUS_BARS
+                            | 0x00000010, // APPEARANCE_LIGHT_NAVIGATION_BARS
+                            0x00000008 | 0x00000010);
+            else
+                insetsController.callMethod<void>(
+                            "setSystemBarsAppearance", "(II)V",
+                            0, 0x00000008 | 0x00000010);
         }
-        view.callMethod<void>("setSystemUiVisibility", "(I)V", visibility);
         window.callMethod<void>("setStatusBarColor", "(I)V",
                                 colorBackground.rgba());
-        window.callMethod<void>("setNavigationBarColor", "(I)V",
-                                colorBackground.rgba());
+        // Set navigation bar color only if we can also use
+        // SYSTEM_UI_FLAG_LIGHT_NAVIGATION_BAR (API level 26)
+        if (QAndroidApplication::sdkVersion() >= 26)
+            window.callMethod<void>("setNavigationBarColor", "(I)V",
+                                    colorBackground.rgba());
     });
 #endif
 }
@@ -514,7 +520,9 @@ bool AndroidUtils::save([[maybe_unused]]const QString& uri,
         return false;
     auto outputStream = contentResolver.callObjectMethod(
                 "openOutputStream",
-                "(Landroid/net/Uri;)Ljava/io/OutputStream;", uriObj.object());
+                "(Landroid/net/Uri;Ljava/lang/String;)Ljava/io/OutputStream;",
+                uriObj.object(),
+                QJniObject::fromString("wt").object<jstring>());
     QJniEnvironment env;
     if (checkException())
         return false;
