@@ -9,7 +9,6 @@
 #include <cerrno>
 #include <cstring>
 #include <fstream>
-#include <QClipboard>
 #include <QDateTime>
 #include <QGuiApplication>
 #include <QDir>
@@ -973,30 +972,6 @@ void GameModel::newGame()
     updateProperties();
 }
 
-bool GameModel::openClipboard()
-{
-    auto text = QGuiApplication::clipboard()->text();
-    if (text.isEmpty())
-    {
-        m_error = tr("Clipboard is empty.");
-        return false;
-    }
-    istringstream in(text.toLocal8Bit().constData());
-    bool result;
-    if (openStream(in))
-    {
-        auto& root = m_game.get_root();
-        if (! has_setup(root) && root.has_children())
-            goEnd();
-        result = true;
-    }
-    else
-        result = false;
-    clearFile();
-    setIsModified(true);
-    return result;
-}
-
 bool GameModel::openFile(const QString& file)
 {
 #ifdef Q_OS_ANDROID
@@ -1507,25 +1482,6 @@ QString GameModel::suggestGameFileName(const QUrl& folder)
     return suggestFileName(folder, QStringLiteral("blksgf"));
 }
 
-QString GameModel::suggestNewFolderName(const QUrl& folder)
-{
-    auto localFolder = folder.toLocalFile();
-    QString file = localFolder;
-    if (! file.endsWith('/'))
-        file.append('/');
-    file.append(tr("New Folder"));
-    if (QFileInfo::exists(file))
-        for (unsigned i = 1; ; ++i)
-        {
-            //: The argument is a number, which will be increased if a
-            //: folder with the same name already exists
-            file = localFolder + '/' + tr("New Folder %1").arg(i);
-            if (! QFileInfo::exists(file))
-                break;
-        }
-    return QUrl::fromLocalFile(file).fileName();
-}
-
 void GameModel::truncate()
 {
     if (! m_game.get_current().has_parent())
