@@ -149,8 +149,6 @@ public:
 
     Q_INVOKABLE bool openByteArray(const QByteArray& byteArray);
 
-    Q_INVOKABLE bool openClipboard();
-
     Q_INVOKABLE bool openFile(const QString& file);
 
     Q_INVOKABLE PieceModel* preparePiece(GameMove* move);
@@ -234,8 +232,6 @@ public:
 
     Q_INVOKABLE QString suggestGameFileName(const QUrl& folder);
 
-    Q_INVOKABLE static QString suggestNewFolderName(const QUrl& folder);
-
     Q_INVOKABLE QString getError() const { return m_error; }
 
     Q_INVOKABLE QVariantList getPieceModels(int color);
