@@ -6,6 +6,7 @@
 
 #include "RatingModel.h"
 
+#include <limits>
 #include <QDateTime>
 #include <QDir>
 #include <QFileInfo>
@@ -20,13 +21,13 @@ using libpentobi_mcts::Player;
 
 namespace {
 
-const int maxSavedGames = 50;
+const qsizetype maxSavedGames = 50;
 
 } // namespace
 
 //-----------------------------------------------------------------------------
 
-TableModel::TableModel(QObject* parent, const QVector<RatedGameInfo>& history)
+TableModel::TableModel(QObject* parent, const QList<RatedGameInfo>& history)
     : QAbstractTableModel(parent),
       m_history(history)
 {
@@ -34,7 +35,9 @@ TableModel::TableModel(QObject* parent, const QVector<RatedGameInfo>& history)
 
 int TableModel::rowCount([[maybe_unused]] const QModelIndex& parent) const
 {
-    return m_history.length() + 1;
+    qsizetype length = min(m_history.length(), maxSavedGames);
+    static_assert(maxSavedGames < numeric_limits<int>::max());
+    return static_cast<int>(length + 1);
 }
 
 int TableModel::columnCount([[maybe_unused]] const QModelIndex& parent) const
@@ -231,7 +234,7 @@ int RatingModel::getNextLevel(int maxLevel) const
     return level;
 }
 
-const QVector<qreal>& RatingModel::ratingHistory()
+const QList<double>& RatingModel::ratingHistory()
 {
     m_ratingHistory.clear();
     m_ratingHistory.reserve(m_history.length());
@@ -258,7 +261,7 @@ void RatingModel::saveSettings()
         settings.setValue(QStringLiteral("best_rating"),
                           round(m_bestRating.get()));
     }
-    QVector<RatedGameInfo> newHistory;
+    QList<RatedGameInfo> newHistory;
     newHistory.reserve(m_history.size());
     for (auto& info : m_history)
     {
@@ -331,7 +334,10 @@ void RatingModel::setGameVariant(const QString& gameVariant)
         auto date = settings.value(QStringLiteral("date")).toString();
         auto level = settings.value(QStringLiteral("level")).toInt();
         auto rating = settings.value(QStringLiteral("rating")).toDouble();
-        m_history.append({number, color, level, result, rating, date});
+        if (i < maxSavedGames)
+            m_history.append({number, color, level, result, rating, date});
+        else
+            QFile::remove(getFile(number));
     }
     settings.endArray();
     emit ratingHistoryChanged();
