@@ -93,10 +93,6 @@
         <extracomment>Move marking/None</extracomment>
         <translation>Keine</translation>
     </message>
-    <message>
-        <source>Animations</source>
-        <translation>Animationen</translation>
-    </message>
     <message>
         <source>Show comment:</source>
         <translation>Kommentar zeigen:</translation>
@@ -137,17 +133,6 @@
         <translation>Textdateien</translation>
     </message>
 </context>
-<context>
-    <name>AsciiArtSaveDialogNative</name>
-    <message>
-        <source>Export ASCII Art</source>
-        <translation>ASCII-Art exportieren</translation>
-    </message>
-    <message>
-        <source>Text files</source>
-        <translation>Textdateien</translation>
-    </message>
-</context>
 <context>
     <name>BoardContextMenu</name>
     <message>
@@ -405,10 +390,6 @@
         <source>Invalid Blokus SGF file. (%1)</source>
         <translation>Ungültige Blokus-SGF-Datei. (%1)</translation>
     </message>
-    <message>
-        <source>Clipboard is empty.</source>
-        <translation>Zwischenablage ist leer.</translation>
-    </message>
     <message>
         <source>Untitled</source>
         <translation>Unbenannt</translation>
@@ -532,21 +513,6 @@
         <translation>JPEG-Bilddateien</translation>
     </message>
 </context>
-<context>
-    <name>ImageSaveDialogNative</name>
-    <message>
-        <source>Save Image</source>
-        <translation>Grafik speichern</translation>
-    </message>
-    <message>
-        <source>PNG image files</source>
-        <translation>PNG-Bilddateien</translation>
-    </message>
-    <message>
-        <source>JPEG image files</source>
-        <translation>JPEG-Bilddateien</translation>
-    </message>
-</context>
 <context>
     <name>InitialRatingDialog</name>
     <message>
@@ -1001,10 +967,6 @@
         <source>Game Variant…</source>
         <translation>Spielvariante …</translation>
     </message>
-    <message>
-        <source>Open Clipboard</source>
-        <translation>Zwischenablage öffnen</translation>
-    </message>
 </context>
 <context>
     <name>MenuGo</name>
@@ -1109,13 +1071,6 @@
         <translation>Keine Annotierung</translation>
     </message>
 </context>
-<context>
-    <name>NewFolderDialog</name>
-    <message>
-        <source>Folder name:</source>
-        <translation>Name des Ordners:</translation>
-    </message>
-</context>
 <context>
     <name>OpenDialog</name>
     <message>
@@ -1126,32 +1081,6 @@
         <source>Blokus games</source>
         <translation>Blokus-Partien</translation>
     </message>
-</context>
-<context>
-    <name>OpenDialogNative</name>
-    <message>
-        <source>Open</source>
-        <translation>Öffnen</translation>
-    </message>
-    <message>
-        <source>Blokus games</source>
-        <translation>Blokus-Partien</translation>
-    </message>
-</context>
-<context>
-    <name>PentobiFileDialog</name>
-    <message>
-        <source>Overwrite file?</source>
-        <translation>Datei überschreiben?</translation>
-    </message>
-    <message>
-        <source>Open</source>
-        <translation>Öffnen</translation>
-    </message>
-    <message>
-        <source>Save</source>
-        <translation>Speichern</translation>
-    </message>
     <message>
         <source>All files</source>
         <translation>Alle Dateien</translation>
@@ -1355,17 +1284,6 @@
         <translation>Blokus-Partien</translation>
     </message>
 </context>
-<context>
-    <name>SaveDialogNative</name>
-    <message>
-        <source>Save</source>
-        <translation>Speichern</translation>
-    </message>
-    <message>
-        <source>Blokus games</source>
-        <translation>Blokus-Partien</translation>
-    </message>
-</context>
 <context>
     <name>TableModel</name>
     <message>
