@@ -95,10 +95,6 @@
         <extracomment>Move marking/None</extracomment>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Animations</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Show comment:</source>
         <translation type="unfinished"></translation>
@@ -139,17 +135,6 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>AsciiArtSaveDialogNative</name>
-    <message>
-        <source>Export ASCII Art</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Text files</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>BoardContextMenu</name>
     <message>
@@ -407,10 +392,6 @@
         <source>Invalid Blokus SGF file. (%1)</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Clipboard is empty.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Untitled</source>
         <translation type="unfinished"></translation>
@@ -534,21 +515,6 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>ImageSaveDialogNative</name>
-    <message>
-        <source>Save Image</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>PNG image files</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>JPEG image files</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>InitialRatingDialog</name>
     <message>
@@ -1003,10 +969,6 @@
         <source>Game Variant…</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Open Clipboard</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>MenuGo</name>
@@ -1111,13 +1073,6 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>NewFolderDialog</name>
-    <message>
-        <source>Folder name:</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>OpenDialog</name>
     <message>
@@ -1128,32 +1083,6 @@
         <source>Blokus games</source>
         <translation type="unfinished"></translation>
     </message>
-</context>
-<context>
-    <name>OpenDialogNative</name>
-    <message>
-        <source>Open</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Blokus games</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
-<context>
-    <name>PentobiFileDialog</name>
-    <message>
-        <source>Overwrite file?</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Open</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Save</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>All files</source>
         <translation type="unfinished"></translation>
@@ -1357,17 +1286,6 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>SaveDialogNative</name>
-    <message>
-        <source>Save</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Blokus games</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>TableModel</name>
     <message>
