@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
 <context>
     <name>AboutDialog</name>
     <message>
@@ -192,6 +192,24 @@
         <translation>Niveau %1</translation>
     </message>
 </context>
+<context>
+    <name>DocbookReader</name>
+    <message>
+        <source>Previous</source>
+        <extracomment>Go to previous page of user manual</extracomment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Contents</source>
+        <extracomment>Go to table of contents of user manual</extracomment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Next</source>
+        <extracomment>Go to next page of user manual</extracomment>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>ExportImageDialog</name>
     <message>
@@ -199,25 +217,6 @@
         <translation>Largeur de l’image :</translation>
     </message>
 </context>
-<context>
-    <name>FileDialog</name>
-    <message>
-        <source>Overwrite file?</source>
-        <translation>Remplacer le fichier ?</translation>
-    </message>
-    <message>
-        <source>Open</source>
-        <translation>Ouvrir</translation>
-    </message>
-    <message>
-        <source>Save</source>
-        <translation>Enregistrer</translation>
-    </message>
-    <message>
-        <source>All files</source>
-        <translation>Tous les fichiers</translation>
-    </message>
-</context>
 <context>
     <name>GameInfoDialog</name>
     <message>
@@ -504,7 +503,7 @@
     <name>HelpWindow</name>
     <message>
         <source>Pentobi Help</source>
-        <translation>Aide de Pentobi</translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -568,10 +567,6 @@
         <source>Your rating stays at %1.</source>
         <translation>Votre classement reste à %1.</translation>
     </message>
-    <message>
-        <source>No permission to access storage</source>
-        <translation>Aucune autorisation d’accès au stockage</translation>
-    </message>
     <message>
         <source>Delete all rating information for the current game variant?</source>
         <translation>Supprimer toutes les informations de classement de l’actuelle variante du jeu ?</translation>
@@ -1007,19 +1002,6 @@
         <translation>Rapportez une erreur</translation>
     </message>
 </context>
-<context>
-    <name>MenuItem</name>
-    <message>
-        <source>Ctrl</source>
-        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
-        <translation>Ctrl</translation>
-    </message>
-    <message>
-        <source>Shift</source>
-        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
-        <translation>Maj</translation>
-    </message>
-</context>
 <context>
     <name>MenuRecentFiles</name>
     <message>
@@ -1123,6 +1105,110 @@
         <translation>Parties de Blokus</translation>
     </message>
 </context>
+<context>
+    <name>PentobiFileDialog</name>
+    <message>
+        <source>Overwrite file?</source>
+        <translation>Remplacer le fichier ?</translation>
+    </message>
+    <message>
+        <source>Open</source>
+        <translation>Ouvrir</translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation>Enregistrer</translation>
+    </message>
+    <message>
+        <source>All files</source>
+        <translation>Tous les fichiers</translation>
+    </message>
+</context>
+<context>
+    <name>PentobiMenuItem</name>
+    <message>
+        <source>Ctrl</source>
+        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
+        <translation>Ctrl</translation>
+    </message>
+    <message>
+        <source>Shift</source>
+        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
+        <translation>Maj</translation>
+    </message>
+</context>
+<context>
+    <name>PentobiToolBar</name>
+    <message>
+        <source>Start a new game</source>
+        <translation>Commencer une nouvelle partie</translation>
+    </message>
+    <message>
+        <source>Start a rated game</source>
+        <translation>Commencer une partie classée</translation>
+    </message>
+    <message>
+        <source>Set the colors played by the computer</source>
+        <translation>Définir les couleurs joué par l’ordinateur</translation>
+    </message>
+    <message>
+        <source>Make the computer continue to play the current color</source>
+        <translation>Faire que l’ordinateur continue à jouer la couleur actuelle</translation>
+    </message>
+    <message>
+        <source>Make the computer play the current color</source>
+        <translation>Faire que l’ordinateur joue la couleur actuelle</translation>
+    </message>
+    <message>
+        <source>Go to beginning of game</source>
+        <translation>Aller en début de partie</translation>
+    </message>
+    <message>
+        <source>Go ten moves backward</source>
+        <translation>Revenir dix coups en arrière</translation>
+    </message>
+    <message>
+        <source>Go one move backward</source>
+        <translation>Revenir un coup en arrière</translation>
+    </message>
+    <message>
+        <source>Go one move forward</source>
+        <translation>Avancer d’un coup</translation>
+    </message>
+    <message>
+        <source>Go ten moves forward</source>
+        <translation>Avancer de dix coups</translation>
+    </message>
+    <message>
+        <source>Go to end of moves</source>
+        <translation>Aller à la fin de coups</translation>
+    </message>
+    <message>
+        <source>Go to previous variation</source>
+        <translation>Aller à la variation précédente</translation>
+    </message>
+    <message>
+        <source>Go to next variation</source>
+        <translation>Aller à la variation suivante</translation>
+    </message>
+    <message>
+        <source>Abort game analysis</source>
+        <translation>Abandonner l&apos;analyse</translation>
+    </message>
+    <message>
+        <source>Abort computer move</source>
+        <translation>Abandonner le coup de l&apos;ordinateur</translation>
+    </message>
+    <message>
+        <source>Undo move</source>
+        <extracomment>Tooltip for Undo button</extracomment>
+        <translation>Annuler le coup</translation>
+    </message>
+    <message>
+        <source>Open menu</source>
+        <translation>Ouvrir le menu</translation>
+    </message>
+</context>
 <context>
     <name>RatingDialog</name>
     <message>
@@ -1292,78 +1378,6 @@
         <translation>Egalité</translation>
     </message>
 </context>
-<context>
-    <name>ToolBar</name>
-    <message>
-        <source>Start a new game</source>
-        <translation>Commencer une nouvelle partie</translation>
-    </message>
-    <message>
-        <source>Start a rated game</source>
-        <translation>Commencer une partie classée</translation>
-    </message>
-    <message>
-        <source>Set the colors played by the computer</source>
-        <translation>Définir les couleurs joué par l’ordinateur</translation>
-    </message>
-    <message>
-        <source>Make the computer continue to play the current color</source>
-        <translation>Faire que l’ordinateur continue à jouer la couleur actuelle</translation>
-    </message>
-    <message>
-        <source>Make the computer play the current color</source>
-        <translation>Faire que l’ordinateur joue la couleur actuelle</translation>
-    </message>
-    <message>
-        <source>Go to beginning of game</source>
-        <translation>Aller en début de partie</translation>
-    </message>
-    <message>
-        <source>Go ten moves backward</source>
-        <translation>Revenir dix coups en arrière</translation>
-    </message>
-    <message>
-        <source>Go one move backward</source>
-        <translation>Revenir un coup en arrière</translation>
-    </message>
-    <message>
-        <source>Go one move forward</source>
-        <translation>Avancer d’un coup</translation>
-    </message>
-    <message>
-        <source>Go ten moves forward</source>
-        <translation>Avancer de dix coups</translation>
-    </message>
-    <message>
-        <source>Go to end of moves</source>
-        <translation>Aller à la fin de coups</translation>
-    </message>
-    <message>
-        <source>Go to previous variation</source>
-        <translation>Aller à la variation précédente</translation>
-    </message>
-    <message>
-        <source>Go to next variation</source>
-        <translation>Aller à la variation suivante</translation>
-    </message>
-    <message>
-        <source>Abort game analysis</source>
-        <translation>Abandonner l&apos;analyse</translation>
-    </message>
-    <message>
-        <source>Abort computer move</source>
-        <translation>Abandonner le coup de l&apos;ordinateur</translation>
-    </message>
-    <message>
-        <source>Undo move</source>
-        <extracomment>Tooltip for Undo button</extracomment>
-        <translation>Annuler le coup</translation>
-    </message>
-    <message>
-        <source>Open menu</source>
-        <translation>Ouvrir le menu</translation>
-    </message>
-</context>
 <context>
     <name>main</name>
     <message>
