@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
 <context>
     <name>AboutDialog</name>
     <message>
@@ -49,7 +49,7 @@
     </message>
     <message>
         <source>Show variations</source>
-        <translation>Показать варианты</translation>
+        <translation>Показать вариации</translation>
     </message>
     <message>
         <source>Light</source>
@@ -192,6 +192,24 @@
         <translation>Уровень %1</translation>
     </message>
 </context>
+<context>
+    <name>DocbookReader</name>
+    <message>
+        <source>Previous</source>
+        <extracomment>Go to previous page of user manual</extracomment>
+        <translation>Пред.</translation>
+    </message>
+    <message>
+        <source>Contents</source>
+        <extracomment>Go to table of contents of user manual</extracomment>
+        <translation>Начало</translation>
+    </message>
+    <message>
+        <source>Next</source>
+        <extracomment>Go to next page of user manual</extracomment>
+        <translation>След.</translation>
+    </message>
+</context>
 <context>
     <name>ExportImageDialog</name>
     <message>
@@ -199,25 +217,6 @@
         <translation>Ширина изображения:</translation>
     </message>
 </context>
-<context>
-    <name>FileDialog</name>
-    <message>
-        <source>Overwrite file?</source>
-        <translation>Перезаписать файл?</translation>
-    </message>
-    <message>
-        <source>Open</source>
-        <translation>Открыть</translation>
-    </message>
-    <message>
-        <source>Save</source>
-        <translation>Сохранить</translation>
-    </message>
-    <message>
-        <source>All files</source>
-        <translation>Все файлы</translation>
-    </message>
-</context>
 <context>
     <name>GameInfoDialog</name>
     <message>
@@ -550,7 +549,7 @@
     </message>
     <message>
         <source>Game analysis is only possible in main variation.</source>
-        <translation>Анализ игры возможен только в основном варианте.</translation>
+        <translation>Анализ игры возможен только в основной вариации.</translation>
     </message>
     <message>
         <source>Autosaved game was changed by another instance of Pentobi. Overwrite?</source>
@@ -568,17 +567,13 @@
         <source>Your rating stays at %1.</source>
         <translation>Ваш рейтинг остается на уровне %1.</translation>
     </message>
-    <message>
-        <source>No permission to access storage</source>
-        <translation>Нет разрешения на доступ к хранилищу</translation>
-    </message>
     <message>
         <source>Delete all rating information for the current game variant?</source>
         <translation>Удалить всю информацию рейтинга для текущей игры?</translation>
     </message>
     <message>
         <source>Delete all variations?</source>
-        <translation>Удалить все варианты?</translation>
+        <translation>Удалить все вариации?</translation>
     </message>
     <message>
         <source>Save failed.</source>
@@ -706,7 +701,7 @@
     </message>
     <message>
         <source>Variations deleted</source>
-        <translation>Варианты удалены</translation>
+        <translation>Вариации удалены</translation>
     </message>
     <message>
         <source>File saved</source>
@@ -738,7 +733,7 @@
     </message>
     <message>
         <source>Variation is now %1</source>
-        <translation>Текущий вариант %1</translation>
+        <translation>Текущая вариация %1</translation>
     </message>
     <message>
         <source>Children truncated</source>
@@ -770,7 +765,7 @@
     </message>
     <message>
         <source>Main Variation</source>
-        <translation>Основной вариант</translation>
+        <translation>Основная вариация</translation>
     </message>
     <message>
         <source>Beginning of Branch</source>
@@ -828,7 +823,7 @@
     <message>
         <source>Play Move</source>
         <extracomment>Play a single move</extracomment>
-        <translation>Воспроизвести ход</translation>
+        <translation>Сыграть ход</translation>
     </message>
     <message>
         <source>Quit</source>
@@ -906,21 +901,21 @@
     </message>
     <message>
         <source>Make Main Variation</source>
-        <translation>Сделать основным вариантом</translation>
+        <translation>Сделать основной вариацией</translation>
     </message>
     <message>
         <source>Variation Up</source>
         <extracomment>Short for Move Variation Up</extracomment>
-        <translation>Вариант вверх</translation>
+        <translation>Вариация выше</translation>
     </message>
     <message>
         <source>Variation Down</source>
         <extracomment>Short for Move Variation Down</extracomment>
-        <translation>Вариант вниз</translation>
+        <translation>Вариант ниже</translation>
     </message>
     <message>
         <source>Delete Variations</source>
-        <translation>Удалить варианты</translation>
+        <translation>Удалить вариации</translation>
     </message>
     <message>
         <source>Truncate</source>
@@ -1007,19 +1002,6 @@
         <translation>Сообщить об ошибке</translation>
     </message>
 </context>
-<context>
-    <name>MenuItem</name>
-    <message>
-        <source>Ctrl</source>
-        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
-        <translation>Ctrl</translation>
-    </message>
-    <message>
-        <source>Shift</source>
-        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
-        <translation>Shift</translation>
-    </message>
-</context>
 <context>
     <name>MenuRecentFiles</name>
     <message>
@@ -1123,6 +1105,110 @@
         <translation>Игры Блокус</translation>
     </message>
 </context>
+<context>
+    <name>PentobiFileDialog</name>
+    <message>
+        <source>Overwrite file?</source>
+        <translation>Перезаписать файл?</translation>
+    </message>
+    <message>
+        <source>Open</source>
+        <translation>Открыть</translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation>Сохранить</translation>
+    </message>
+    <message>
+        <source>All files</source>
+        <translation>Все файлы</translation>
+    </message>
+</context>
+<context>
+    <name>PentobiMenuItem</name>
+    <message>
+        <source>Ctrl</source>
+        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
+        <translation>Ctrl</translation>
+    </message>
+    <message>
+        <source>Shift</source>
+        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
+        <translation>Shift</translation>
+    </message>
+</context>
+<context>
+    <name>PentobiToolBar</name>
+    <message>
+        <source>Start a new game</source>
+        <translation>Начать новую игру</translation>
+    </message>
+    <message>
+        <source>Start a rated game</source>
+        <translation>Начать рейтинговую игру</translation>
+    </message>
+    <message>
+        <source>Set the colors played by the computer</source>
+        <translation>Установите цвета игроков компьютера</translation>
+    </message>
+    <message>
+        <source>Make the computer continue to play the current color</source>
+        <translation>Сделать так, чтобы компьютер продолжал играть в текущем цвете</translation>
+    </message>
+    <message>
+        <source>Make the computer play the current color</source>
+        <translation>Сделать так, чтобы компьютер играл в текущем цвете</translation>
+    </message>
+    <message>
+        <source>Go to beginning of game</source>
+        <translation>К началу игры</translation>
+    </message>
+    <message>
+        <source>Go ten moves backward</source>
+        <translation>На десять ходов назад</translation>
+    </message>
+    <message>
+        <source>Go one move backward</source>
+        <translation>На один шаг назад</translation>
+    </message>
+    <message>
+        <source>Go one move forward</source>
+        <translation>Вперед на один ход</translation>
+    </message>
+    <message>
+        <source>Go ten moves forward</source>
+        <translation>Вперед на десять ходов</translation>
+    </message>
+    <message>
+        <source>Go to end of moves</source>
+        <translation>К концу ходов</translation>
+    </message>
+    <message>
+        <source>Go to previous variation</source>
+        <translation>К предыдущему варианту</translation>
+    </message>
+    <message>
+        <source>Go to next variation</source>
+        <translation>К следующему варианту</translation>
+    </message>
+    <message>
+        <source>Abort game analysis</source>
+        <translation>Прервать анализ игры</translation>
+    </message>
+    <message>
+        <source>Abort computer move</source>
+        <translation>Прервать перемещение компьютера</translation>
+    </message>
+    <message>
+        <source>Undo move</source>
+        <extracomment>Tooltip for Undo button</extracomment>
+        <translation>Отменить Ход</translation>
+    </message>
+    <message>
+        <source>Open menu</source>
+        <translation>Открыть меню</translation>
+    </message>
+</context>
 <context>
     <name>RatingDialog</name>
     <message>
@@ -1233,6 +1319,10 @@
         <source>Recent development:</source>
         <translation>Последняя разработка:</translation>
     </message>
+    <message>
+        <source>Open Game %1</source>
+        <translation>Открыть Игру %1</translation>
+    </message>
 </context>
 <context>
     <name>SaveDialog</name>
@@ -1288,78 +1378,6 @@
         <translation>Ничья</translation>
     </message>
 </context>
-<context>
-    <name>ToolBar</name>
-    <message>
-        <source>Start a new game</source>
-        <translation>Начать новую игру</translation>
-    </message>
-    <message>
-        <source>Start a rated game</source>
-        <translation>Начать рейтинговую игру</translation>
-    </message>
-    <message>
-        <source>Set the colors played by the computer</source>
-        <translation>Установите цвета игроков компьютера</translation>
-    </message>
-    <message>
-        <source>Make the computer continue to play the current color</source>
-        <translation>Сделать так, чтобы компьютер продолжал играть в текущем цвете</translation>
-    </message>
-    <message>
-        <source>Make the computer play the current color</source>
-        <translation>Сделать так, чтобы компьютер играл в текущем цвете</translation>
-    </message>
-    <message>
-        <source>Go to beginning of game</source>
-        <translation>К началу игры</translation>
-    </message>
-    <message>
-        <source>Go ten moves backward</source>
-        <translation>На десять ходов назад</translation>
-    </message>
-    <message>
-        <source>Go one move backward</source>
-        <translation>На один шаг назад</translation>
-    </message>
-    <message>
-        <source>Go one move forward</source>
-        <translation>Вперед на один ход</translation>
-    </message>
-    <message>
-        <source>Go ten moves forward</source>
-        <translation>Вперед на десять ходов</translation>
-    </message>
-    <message>
-        <source>Go to end of moves</source>
-        <translation>К концу ходов</translation>
-    </message>
-    <message>
-        <source>Go to previous variation</source>
-        <translation>К предыдущему варианту</translation>
-    </message>
-    <message>
-        <source>Go to next variation</source>
-        <translation>К следующему варианту</translation>
-    </message>
-    <message>
-        <source>Abort game analysis</source>
-        <translation>Прервать анализ игры</translation>
-    </message>
-    <message>
-        <source>Abort computer move</source>
-        <translation>Прервать перемещение компьютера</translation>
-    </message>
-    <message>
-        <source>Undo move</source>
-        <extracomment>Tooltip for Undo button</extracomment>
-        <translation>Отменить Ход</translation>
-    </message>
-    <message>
-        <source>Open menu</source>
-        <translation>Открыть меню</translation>
-    </message>
-</context>
 <context>
     <name>main</name>
     <message>
