@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
 <context>
     <name>AboutDialog</name>
     <message>
@@ -192,6 +192,24 @@
         <translation>等级 %1</translation>
     </message>
 </context>
+<context>
+    <name>DocbookReader</name>
+    <message>
+        <source>Previous</source>
+        <extracomment>Go to previous page of user manual</extracomment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Contents</source>
+        <extracomment>Go to table of contents of user manual</extracomment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Next</source>
+        <extracomment>Go to next page of user manual</extracomment>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>ExportImageDialog</name>
     <message>
@@ -199,25 +217,6 @@
         <translation>图像宽度：</translation>
     </message>
 </context>
-<context>
-    <name>FileDialog</name>
-    <message>
-        <source>Overwrite file?</source>
-        <translation>覆盖文件？</translation>
-    </message>
-    <message>
-        <source>Open</source>
-        <translation>打开</translation>
-    </message>
-    <message>
-        <source>Save</source>
-        <translation>保存</translation>
-    </message>
-    <message>
-        <source>All files</source>
-        <translation>所有文件</translation>
-    </message>
-</context>
 <context>
     <name>GameInfoDialog</name>
     <message>
@@ -504,7 +503,7 @@
     <name>HelpWindow</name>
     <message>
         <source>Pentobi Help</source>
-        <translation>Pentobi 帮助</translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -568,10 +567,6 @@
         <source>Your rating stays at %1.</source>
         <translation>您的等级仍然是%1。</translation>
     </message>
-    <message>
-        <source>No permission to access storage</source>
-        <translation>没有访问存储器的权限</translation>
-    </message>
     <message>
         <source>Delete all rating information for the current game variant?</source>
         <translation>删除此游戏规则下的所有等级数据？</translation>
@@ -1007,19 +1002,6 @@
         <translation>报告bug</translation>
     </message>
 </context>
-<context>
-    <name>MenuItem</name>
-    <message>
-        <source>Ctrl</source>
-        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
-        <translation>Ctrl</translation>
-    </message>
-    <message>
-        <source>Shift</source>
-        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
-        <translation>Shift</translation>
-    </message>
-</context>
 <context>
     <name>MenuRecentFiles</name>
     <message>
@@ -1123,6 +1105,110 @@
         <translation>角斗士游戏</translation>
     </message>
 </context>
+<context>
+    <name>PentobiFileDialog</name>
+    <message>
+        <source>Overwrite file?</source>
+        <translation>覆盖文件？</translation>
+    </message>
+    <message>
+        <source>Open</source>
+        <translation>打开</translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation>保存</translation>
+    </message>
+    <message>
+        <source>All files</source>
+        <translation>所有文件</translation>
+    </message>
+</context>
+<context>
+    <name>PentobiMenuItem</name>
+    <message>
+        <source>Ctrl</source>
+        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Shift</source>
+        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>PentobiToolBar</name>
+    <message>
+        <source>Start a new game</source>
+        <translation>开始新游戏</translation>
+    </message>
+    <message>
+        <source>Start a rated game</source>
+        <translation>开始一局等级赛</translation>
+    </message>
+    <message>
+        <source>Set the colors played by the computer</source>
+        <translation>设置电脑控制的颜色</translation>
+    </message>
+    <message>
+        <source>Make the computer continue to play the current color</source>
+        <translation>使电脑执当前颜色继续</translation>
+    </message>
+    <message>
+        <source>Make the computer play the current color</source>
+        <translation>使电脑执当前颜色</translation>
+    </message>
+    <message>
+        <source>Go to beginning of game</source>
+        <translation>转到棋局开始</translation>
+    </message>
+    <message>
+        <source>Go ten moves backward</source>
+        <translation>向后跳转10步</translation>
+    </message>
+    <message>
+        <source>Go one move backward</source>
+        <translation>向后跳转一步</translation>
+    </message>
+    <message>
+        <source>Go one move forward</source>
+        <translation>向前跳转一步</translation>
+    </message>
+    <message>
+        <source>Go ten moves forward</source>
+        <translation>向前跳转10步</translation>
+    </message>
+    <message>
+        <source>Go to end of moves</source>
+        <translation>转到棋局末尾</translation>
+    </message>
+    <message>
+        <source>Go to previous variation</source>
+        <translation>转到上一变例</translation>
+    </message>
+    <message>
+        <source>Go to next variation</source>
+        <translation>转到下一变例</translation>
+    </message>
+    <message>
+        <source>Abort game analysis</source>
+        <translation>取消棋局分析</translation>
+    </message>
+    <message>
+        <source>Abort computer move</source>
+        <translation>取消电脑行棋</translation>
+    </message>
+    <message>
+        <source>Undo move</source>
+        <extracomment>Tooltip for Undo button</extracomment>
+        <translation>撤销一步</translation>
+    </message>
+    <message>
+        <source>Open menu</source>
+        <translation>打开菜单</translation>
+    </message>
+</context>
 <context>
     <name>RatingDialog</name>
     <message>
@@ -1292,78 +1378,6 @@
         <translation>平</translation>
     </message>
 </context>
-<context>
-    <name>ToolBar</name>
-    <message>
-        <source>Start a new game</source>
-        <translation>开始新游戏</translation>
-    </message>
-    <message>
-        <source>Start a rated game</source>
-        <translation>开始一局等级赛</translation>
-    </message>
-    <message>
-        <source>Set the colors played by the computer</source>
-        <translation>设置电脑控制的颜色</translation>
-    </message>
-    <message>
-        <source>Make the computer continue to play the current color</source>
-        <translation>使电脑执当前颜色继续</translation>
-    </message>
-    <message>
-        <source>Make the computer play the current color</source>
-        <translation>使电脑执当前颜色</translation>
-    </message>
-    <message>
-        <source>Go to beginning of game</source>
-        <translation>转到棋局开始</translation>
-    </message>
-    <message>
-        <source>Go ten moves backward</source>
-        <translation>向后跳转10步</translation>
-    </message>
-    <message>
-        <source>Go one move backward</source>
-        <translation>向后跳转一步</translation>
-    </message>
-    <message>
-        <source>Go one move forward</source>
-        <translation>向前跳转一步</translation>
-    </message>
-    <message>
-        <source>Go ten moves forward</source>
-        <translation>向前跳转10步</translation>
-    </message>
-    <message>
-        <source>Go to end of moves</source>
-        <translation>转到棋局末尾</translation>
-    </message>
-    <message>
-        <source>Go to previous variation</source>
-        <translation>转到上一变例</translation>
-    </message>
-    <message>
-        <source>Go to next variation</source>
-        <translation>转到下一变例</translation>
-    </message>
-    <message>
-        <source>Abort game analysis</source>
-        <translation>取消棋局分析</translation>
-    </message>
-    <message>
-        <source>Abort computer move</source>
-        <translation>取消电脑行棋</translation>
-    </message>
-    <message>
-        <source>Undo move</source>
-        <extracomment>Tooltip for Undo button</extracomment>
-        <translation>撤销一步</translation>
-    </message>
-    <message>
-        <source>Open menu</source>
-        <translation>打开菜单</translation>
-    </message>
-</context>
 <context>
     <name>main</name>
     <message>
